@@ -6,22 +6,17 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KCMAPPTSUMMARY_H
-#define KCMAPPTSUMMARY_H
+#pragma once
 
 #include "ui_apptsummaryconfig_base.h"
 #include <KCModule>
 
-extern "C" {
-Q_DECL_EXPORT KCModule *create_apptsummary(QWidget *parent, const char *);
-}
-
 class KCMApptSummary : public KCModule, public Ui::ApptSummaryConfig_Base
 {
     Q_OBJECT
 
 public:
-    explicit KCMApptSummary(QWidget *parent = nullptr);
+    explicit KCMApptSummary(QWidget *parent = nullptr, const QVariantList &args = {});
 
     void load() override;
     void save() override;
@@ -39,4 +34,3 @@ private:
     QButtonGroup *mGroupwareButtonGroup = nullptr;
 };
 
-#endif
